Index: trunk/ppImage/src/ppImageLoop.c
===================================================================
--- trunk/ppImage/src/ppImageLoop.c	(revision 20771)
+++ trunk/ppImage/src/ppImageLoop.c	(revision 21183)
@@ -126,7 +126,7 @@
 	}
 
         // measure various statistics for this image
         if (!ppImagePixelStats(config, stats, options, view)) {
-            ESCAPE("Unable to measures stats for image");
+            ESCAPE("Unable to measures pixel stats for image");
         }
         if (!ppImageMosaicChip(config, options, view, "PPIMAGE.CHIP", "PPIMAGE.OUTPUT")) {
@@ -209,7 +209,7 @@
     }
 
-    // Write out summary statistics
+    // Calculate summary statistics from FPA Metadata
     if (!ppImageMetadataStats(config, stats, options)) {
-        ESCAPE("Unable to write statistics file.");
+        ESCAPE("Unable to determine FPA-level metadata statistics.");
     }
 
@@ -218,5 +218,4 @@
         ESCAPE("save failure for FPA");
     }
-
     psFree(view);
 
@@ -230,4 +229,5 @@
         }
     }
+    psFree (stats);
 
     return true;
@@ -126,7 +126,7 @@
 	}
 
-        // measure various statistics for this image
+        // measure various pixel-based statistics for this image
         if (!ppImagePixelStats(config, stats, options, view)) {
